==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/mining_explanation/v1beta/MajorClaimExplanationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining_explanation.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/mining_explanation/v1beta/major_claim.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class MajorClaimExplanationServiceGrpc {

  private MajorClaimExplanationServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.mining_explanation.v1beta.MajorClaimExplanationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> getMajorClaimMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "MajorClaim",
      requestType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> getMajorClaimMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> getMajorClaimMethod;
    if ((getMajorClaimMethod = MajorClaimExplanationServiceGrpc.getMajorClaimMethod) == null) {
      synchronized (MajorClaimExplanationServiceGrpc.class) {
        if ((getMajorClaimMethod = MajorClaimExplanationServiceGrpc.getMajorClaimMethod) == null) {
          MajorClaimExplanationServiceGrpc.getMajorClaimMethod = getMajorClaimMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "MajorClaim"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse.getDefaultInstance()))
              .setSchemaDescriptor(new MajorClaimExplanationServiceMethodDescriptorSupplier("MajorClaim"))
              .build();
        }
      }
    }
    return getMajorClaimMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static MajorClaimExplanationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceStub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceStub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static MajorClaimExplanationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceBlockingStub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceBlockingStub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static MajorClaimExplanationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceFutureStub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceFutureStub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class MajorClaimExplanationServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getMajorClaimMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getMajorClaimMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest,
                de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse>(
                  this, METHODID_MAJOR_CLAIM)))
          .build();
    }
  }

  /**
   */
  public static final class MajorClaimExplanationServiceStub extends io.grpc.stub.AbstractAsyncStub<MajorClaimExplanationServiceStub> {
    private MajorClaimExplanationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceStub(channel, callOptions);
    }

    /**
     */
    public void majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class MajorClaimExplanationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<MajorClaimExplanationServiceBlockingStub> {
    private MajorClaimExplanationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getMajorClaimMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class MajorClaimExplanationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<MajorClaimExplanationServiceFutureStub> {
    private MajorClaimExplanationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> majorClaim(
        de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_MAJOR_CLAIM = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final MajorClaimExplanationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(MajorClaimExplanationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_MAJOR_CLAIM:
          serviceImpl.majorClaim((de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class MajorClaimExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    MajorClaimExplanationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("MajorClaimExplanationService");
    }
  }

  private static final class MajorClaimExplanationServiceFileDescriptorSupplier
      extends MajorClaimExplanationServiceBaseDescriptorSupplier {
    MajorClaimExplanationServiceFileDescriptorSupplier() {}
  }

  private static final class MajorClaimExplanationServiceMethodDescriptorSupplier
      extends MajorClaimExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    MajorClaimExplanationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (MajorClaimExplanationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new MajorClaimExplanationServiceFileDescriptorSupplier())
              .addMethod(getMajorClaimMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.5-sources.jar: de/uni_trier/recap/arg_services/mining_explanation/v1beta/MajorClaimExplanationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining_explanation.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/mining_explanation/v1beta/major_claim.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class MajorClaimExplanationServiceGrpc {

  private MajorClaimExplanationServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.mining_explanation.v1beta.MajorClaimExplanationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> getMajorClaimMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "MajorClaim",
      requestType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> getMajorClaimMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> getMajorClaimMethod;
    if ((getMajorClaimMethod = MajorClaimExplanationServiceGrpc.getMajorClaimMethod) == null) {
      synchronized (MajorClaimExplanationServiceGrpc.class) {
        if ((getMajorClaimMethod = MajorClaimExplanationServiceGrpc.getMajorClaimMethod) == null) {
          MajorClaimExplanationServiceGrpc.getMajorClaimMethod = getMajorClaimMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "MajorClaim"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse.getDefaultInstance()))
              .setSchemaDescriptor(new MajorClaimExplanationServiceMethodDescriptorSupplier("MajorClaim"))
              .build();
        }
      }
    }
    return getMajorClaimMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static MajorClaimExplanationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceStub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceStub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static MajorClaimExplanationServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceBlockingV2Stub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static MajorClaimExplanationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceBlockingStub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceBlockingStub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static MajorClaimExplanationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<MajorClaimExplanationServiceFutureStub>() {
        @java.lang.Override
        public MajorClaimExplanationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new MajorClaimExplanationServiceFutureStub(channel, callOptions);
        }
      };
    return MajorClaimExplanationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getMajorClaimMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service MajorClaimExplanationService.
   */
  public static abstract class MajorClaimExplanationServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return MajorClaimExplanationServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service MajorClaimExplanationService.
   */
  public static final class MajorClaimExplanationServiceStub
      extends io.grpc.stub.AbstractAsyncStub<MajorClaimExplanationServiceStub> {
    private MajorClaimExplanationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceStub(channel, callOptions);
    }

    /**
     */
    public void majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service MajorClaimExplanationService.
   */
  public static final class MajorClaimExplanationServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<MajorClaimExplanationServiceBlockingV2Stub> {
    private MajorClaimExplanationServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getMajorClaimMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service MajorClaimExplanationService.
   */
  public static final class MajorClaimExplanationServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<MajorClaimExplanationServiceBlockingStub> {
    private MajorClaimExplanationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse majorClaim(de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getMajorClaimMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service MajorClaimExplanationService.
   */
  public static final class MajorClaimExplanationServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<MajorClaimExplanationServiceFutureStub> {
    private MajorClaimExplanationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected MajorClaimExplanationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new MajorClaimExplanationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse> majorClaim(
        de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getMajorClaimMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_MAJOR_CLAIM = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_MAJOR_CLAIM:
          serviceImpl.majorClaim((de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getMajorClaimMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimRequest,
              de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimResponse>(
                service, METHODID_MAJOR_CLAIM)))
        .build();
  }

  private static abstract class MajorClaimExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    MajorClaimExplanationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining_explanation.v1beta.MajorClaimProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("MajorClaimExplanationService");
    }
  }

  private static final class MajorClaimExplanationServiceFileDescriptorSupplier
      extends MajorClaimExplanationServiceBaseDescriptorSupplier {
    MajorClaimExplanationServiceFileDescriptorSupplier() {}
  }

  private static final class MajorClaimExplanationServiceMethodDescriptorSupplier
      extends MajorClaimExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    MajorClaimExplanationServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (MajorClaimExplanationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new MajorClaimExplanationServiceFileDescriptorSupplier())
              .addMethod(getMajorClaimMethod())
              .build();
        }
      }
    }
    return result;
  }
}
